@@ -160,8 +160,19 @@ class MyWhatify:
                                onlytotal=only_total)
 
     @classmethod
-    def magento_api(cls, api_method: str = None, body: str = None, table: str = None, page: str = None,
+    def magento_api(cls, api_method: str, body: str = None, table: str = None, page: str = None,
                     limit: str = None, addtotal: str = None, onlytotal: str = None):
+        '''
+        magento store api with params in query
+        :param api_method: set the relevant method GET/POST... MANDATORY
+        :param body: body if needed
+        :param table: the specific table
+        :param page: the page number
+        :param limit: the page limit
+        :param add_total:
+        :param only_total:
+        :return:
+        '''
         base_url = cls.magento_magento2url + '?'
         base_vars = ['table', 'page', 'limit', 'addtotal', 'onlytotal']
         for var in base_vars:
